@@ -1,9 +1,30 @@
-#include <QQmlApplicationEngine>
 #include <QCommandLineParser>
-#include <QIcon>
-#include <QFileInfo>
+
 #include <QDate>
 #include <QDirIterator>
+#include <QQmlContext>
+#include <QFileInfo>
+#include <QIcon>
+
+#include <QQmlApplicationEngine>
+
+#include <KI18n/KLocalizedString>
+#include "controllers/lockmanager.h"
+
+#include <MauiKit/Core/mauiapp.h>
+#include <MauiKit/FileBrowsing/fmstatic.h>
+
+#ifdef MPV_AVAILABLE
+#include "backends/mpv/mpvobject.h"
+#endif
+
+#include "models/videosmodel.h"
+#include "models/tagsmodel.h"
+#include "models/youtubemodel.h"
+#include "utils/thumbnailer.h"
+
+#include "utils/clip.h"
+#include "../clip_version.h"
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -11,19 +32,6 @@
 #include <QApplication>
 #endif
 
-#include <KI18n/KLocalizedString>
-
-#include <MauiKit/Core/mauiapp.h>
-#include <MauiKit/FileBrowsing/fmstatic.h>
-
-#include "backends/mpv/mpvobject.h"
-#include "models/videosmodel.h"
-#include "models/tagsmodel.h"
-#include "models/youtubemodel.h"
-
-#include "utils/clip.h"
-#include "../clip_version.h"
-
 #define CLIP_URI "org.maui.clip"
 
 static const  QList<QUrl>  getFolderVideos(const QString &path)
@@ -65,9 +73,7 @@ static const QList<QUrl> openFiles(const QStringList &files)
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_DisableSessionManager, true);
 
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
@@ -77,17 +83,21 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QApplication app(argc, argv);
 #endif
 
+#ifdef MPV_AVAILABLE
     // Qt sets the locale in the QGuiApplication constructor, but libmpv
     // requires the LC_NUMERIC category to be set to "C", so change it back.
     std::setlocale(LC_NUMERIC, "C");
+#endif
+
     app.setOrganizationName("Maui");
     app.setWindowIcon(QIcon(":/img/assets/clip.svg"));
+    QGuiApplication::setDesktopFileName(QStringLiteral("org.kde.clip"));
 
     MauiApp::instance()->setIconName("qrc:/img/assets/clip.svg");
 
     KLocalizedString::setApplicationDomain("clip");
     KAboutData about(QStringLiteral("clip"), i18n("Clip"), CLIP_VERSION_STRING, i18n("Browse and play your videos."),
-                     KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+                     KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
     about.setProductName("maui/clip");
@@ -98,9 +108,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
-    parser.process(app);
 
     about.setupCommandLine(&parser);
+    parser.process(app);
+
     about.processCommandLine(&parser);
 
     const QStringList args = parser.positionalArguments();
@@ -122,13 +133,23 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     }, Qt::QueuedConnection);
 
-    qmlRegisterType<MpvObject>("mpv", 1, 0, "MpvObject");
-
     qmlRegisterType<VideosModel>(CLIP_URI, 1, 0, "Videos");
     qmlRegisterType<TagsModel>(CLIP_URI, 1, 0, "Tags");
     qmlRegisterType<YouTubeModel>(CLIP_URI, 1, 0, "YouTube");
     qmlRegisterSingletonInstance<Clip>(CLIP_URI, 1, 0, "Clip", Clip::instance ());
+    engine.addImageProvider("preview", new Thumbnailer());
+
+#ifdef MPV_AVAILABLE
     qRegisterMetaType<TracksModel*>();
+    qmlRegisterType<MpvObject>("mpv", 1, 0, "MpvObject");
+    qmlRegisterType(QUrl("qrc:/views/player/MPVPlayer.qml"), CLIP_URI, 1, 0, "Video");
+#else
+    qmlRegisterType(QUrl("qrc:/views/player/Player.qml"), CLIP_URI, 1, 0, "Video");
+#endif
+
+    qmlRegisterSingletonType<LockManager>(CLIP_URI, 1, 0, "LockManager", [](QQmlEngine*, QJSEngine*) -> QObject* {
+            return new LockManager;
+        });
 
     engine.load(url);
 
